@@ -1,6 +1,7 @@
 import math
 
 import numpy as np
+import numba
 from ..geometry import (
     hesse_normal_form, convert_segment_to_line, line_from_pluecker,
     convert_rectangle_to_vertices, convert_box_to_vertices)
@@ -32,6 +33,14 @@ def point_to_plane(point, plane_point, plane_normal, signed=False):
     closest_point_plane : array, shape (3,)
         Closest point on plane.
     """
+    return _point_to_plane(point, plane_point, plane_normal, signed)
+
+
+@numba.njit(
+    numba.types.Tuple((numba.float64, numba.float64[::1]))
+    (numba.float64[::1], numba.float64[::1], numba.float64[::1], numba.boolean),
+    cache=True)
+def _point_to_plane(point, plane_point, plane_normal, signed):
     t = np.dot(plane_normal, point - plane_point)
     closest_point_plane = point - t * plane_normal
     if not signed:
@@ -83,8 +92,13 @@ def line_to_plane(
     return dist, line_point, closest_point_plane
 
 
+@numba.njit(
+    numba.types.Tuple((numba.boolean, numba.float64))
+    (numba.float64[::1], numba.float64[::1], numba.float64[::1],
+     numba.float64[::1], numba.float64),
+    cache=False)
 def _line_to_plane(line_point, line_direction, plane_point, plane_normal,
-                   epsilon=1e-6):
+                   epsilon):
     length_of_dir_projected_on_normal = np.dot(line_direction, plane_normal)
     if length_of_dir_projected_on_normal * length_of_dir_projected_on_normal < epsilon:
         # line parallel to plane
@@ -127,6 +141,13 @@ def line_segment_to_plane(
     closest_point_plane : array, shape (3,)
         Closest point on plane.
     """
+    return _line_segment_to_plane(
+        segment_start, segment_end, plane_point, plane_normal, epsilon)
+
+
+@numba.njit(cache=True)
+def _line_segment_to_plane(
+        segment_start, segment_end, plane_point, plane_normal, epsilon):
     segment_direction, segment_length = convert_segment_to_line(
         segment_start, segment_end)
     line_intersects, t = _line_to_plane(
@@ -144,8 +165,8 @@ def line_segment_to_plane(
     else:
         closest_point_segment = segment_start
 
-    dist, closest_point_plane = point_to_plane(
-        closest_point_segment, plane_point, plane_normal)
+    dist, closest_point_plane = _point_to_plane(
+        closest_point_segment, plane_point, plane_normal, False)
     return dist, closest_point_segment, closest_point_plane
 
 
@@ -233,14 +254,15 @@ def plane_to_triangle(plane_point, plane_normal, triangle_points):
     return _plane_to_convex_hull_points(plane_point, plane_normal, triangle_points)
 
 
+@numba.njit(cache=True)
 def _plane_to_convex_hull_points(plane_point, plane_normal, points):
-    ts = np.dot(points - plane_point[np.newaxis], plane_normal)
+    ts = np.dot(points - plane_point.reshape(1, -1), plane_normal)
     min_idx = np.argmin(ts)
     max_idx = np.argmax(ts)
 
     if ts[min_idx] * ts[max_idx] < 0:  # on opposite sides, intersection
-        return line_segment_to_plane(
-            points[min_idx], points[max_idx], plane_point, plane_normal)
+        return _line_segment_to_plane(
+            points[min_idx], points[max_idx], plane_point, plane_normal, 1e-6)
 
     closest_idx = np.argmin(np.abs(ts))
     closest_point = points[closest_idx]
@@ -321,6 +343,7 @@ def plane_to_box(plane_point, plane_normal, box2origin, size):
     return _plane_to_convex_hull_points(plane_point, plane_normal, points)
 
 
+@numba.njit(cache=True)
 def plane_to_ellipsoid(plane_point, plane_normal, ellipsoid2origin, radii):
     """Compute the shortest distance between a plane and an ellipsoid.
 
@@ -372,6 +395,7 @@ def plane_to_ellipsoid(plane_point, plane_normal, ellipsoid2origin, radii):
     return dist, closest_point_plane, closest_point_ellipsoid
 
 
+@numba.njit(cache=True)
 def _ellipsoid_quadric_matrix(ellipsoid2origin, radii):
     R_scaled = ellipsoid2origin[:3, :3] / radii
     return R_scaled.dot(R_scaled.T)
